{# doc
  Produce ``<option>`` node.
#}
{# def
  value: Annotated[str, "posted value after submitted the selected value"],
  id: Annotated[str | None, "unique identifier of the element."] = None,
  selected: Annotated[
    Literal[True],
    "Used to select the option while rendering the form"
  ] = False,
#}
<option value="{{value}}"
  {%- if id %} id="{{id}}" {%- endif %}
  {%- if selected %} selected {%- endif %}>
  {{- content -}}
</option>
