{# def
    id: Annotated[str | None, "identifier of the element."] = None,
    title: Annotated[str | None, "title element of the svg"] = None,
    class_: Annotated[
        str | None, "css class applied to the svg element"
    ] = None,
    mode: Literal["micro","mini","outline","solid"] = "solid"
#}

{% if mode == "micro"%}<icons.micro.Bolt :id="id" :class="attrs.class or ''" :title="title" />
{% elif mode == "mini"%}<icons.mini.Bolt :id="id" :class="attrs.class or ''" :title="title" />
{% elif mode == "outline"%}<icons.outline.Bolt :id="id" :class="attrs.class or ''" :title="title" />
{% elif mode == "solid"%}<icons.solid.Bolt :id="id" :class="attrs.class or ''" :title="title" />
{%endif%}
