{# doc display an error for a field. #}
{# def text: Annotated[str | None, "error message"] #}
{%- if text -%}
<span class="mt-2 text-sm text-danger-500 dark:text-danger-400">{{text}}</span>
{%- endif -%}
