{# doc html ``<textarea>`` node. #}
{# def
  name: Annotated[str, "name of the submitted"],
  id: Annotated[str | None, "unique identifier of the element."],
  aria_label: Annotated[str | None, "aria-label"] = None,
  placeholder: Annotated[
    str | None,
    "brief hint to the user as to what kind of information is expected in the field"
  ] = None,
#}

<textarea name="{{ name }}"
  {%- if id %} id="{{ id }}" {%- endif %}
  {%- if aria_label %} aria-label="{{ aria_label }}" {%- endif %}
  {%- if placeholder %} placeholder="{{ placeholder }}" {%- endif %}
  class="{{attrs.class or INPUT_CLASS}}">
  {{- content -}}
</textarea>
